@@ -44,26 +44,31 @@ package XML::Stream::Parser;
 
 By Ryan Eatmon in January of 2001 for http://jabber.org/
 
+Currently maintained by Darian Anthony Patrick.
+
 =head1 COPYRIGHT
 
-This module is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+Copyright (C) 1998-2004 Jabber Software Foundation http://jabber.org/
+
+This module licensed under the LGPL, version 2.1.
 
 =cut
 
 use strict;
 use vars qw( $VERSION );
 
-$VERSION = "1.23_01";
+$VERSION = "1.23_02";
 
 use XML::Stream::Tree;
 use XML::Stream::Node;
 
 sub new
 {
+    my $class = shift;
+
     my $self = { };
 
-    bless($self);
+    bless($self, $class);
 
     my %args;
     while($#_ >= 0) { $args{ lc pop(@_) } = pop(@_); }
